@@ -89,6 +89,13 @@ class VisualService(Service):
             "ImageStyleConversion": ApiInfo("POST", "/", {"Action": "ImageStyleConversion", "Version": "2020-08-26"}, {}, {}),
             "3DGameCartoon": ApiInfo("POST", "/", {"Action": "3DGameCartoon", "Version": "2020-08-26"}, {}, {}),
             "HairSegment": ApiInfo("POST", "/", {"Action": "HairSegment", "Version": "2020-08-26"}, {}, {}),
+            "OcrSeal": ApiInfo("POST", "/", {"Action": "OcrSeal", "Version": "2021-08-23"}, {}, {}),
+            "OcrPassInvoice": ApiInfo("POST", "/", {"Action": "OcrPassInvoice", "Version": "2021-08-23"}, {}, {}),
+            "OCRTrade": ApiInfo("POST", "/", {"Action": "OCRTrade", "Version": "2020-12-21"}, {}, {}),
+            "OCRRuanzhu": ApiInfo("POST", "/", {"Action": "OCRRuanzhu", "Version": "2020-12-21"}, {}, {}),
+            "OCRCosmeticProduct": ApiInfo("POST", "/", {"Action": "OCRCosmeticProduct", "Version": "2020-12-21"}, {}, {}),
+            "OCRPdf": ApiInfo("POST", "/", {"Action": "OCRPdf", "Version": "2021-08-23"}, {}, {}),
+
         }
         return api_info
 
@@ -525,3 +532,45 @@ class VisualService(Service):
             return res_json
         except Exception as e:
             raise Exception(str(e))
+
+    def ocr_seal(self, form):
+        try:
+            res_json = self.common_handler("OcrSeal", form)
+            return res_json
+        except Exception as e:
+            raise Exception(str(e))
+
+    def ocr_pass_invoice(self, form):
+        try:
+            res_json = self.common_handler("OcrPassInvoice", form)
+            return res_json
+        except Exception as e:
+            raise Exception(str(e))
+
+    def ocr_trade(self, form):
+        try:
+            res_json = self.common_handler("OCRTrade", form)
+            return res_json
+        except Exception as e:
+            raise Exception(str(e))
+    
+    def ocr_ruanzhu(self, form):
+        try:
+            res_json = self.common_handler("OCRRuanzhu", form)
+            return res_json
+        except Exception as e:
+            raise Exception(str(e))
+
+    def ocr_cosmetic_product(self, form):
+        try:
+            res_json = self.common_handler("OCRCosmeticProduct", form)
+            return res_json
+        except Exception as e:
+            raise Exception(str(e))
+
+    def ocr_pdf(self, form):
+        try:
+            res_json = self.common_handler("OCRPdf", form)
+            return res_json
+        except Exception as e:
+            raise Exception(str(e))
\ No newline at end of file
